# Changelog

## [0.4.0](https://github.com/syntropy-systems-oss/whirr/compare/v0.3.0...v0.4.0) (2026-01-14)


### Features

* add Rust worker for minimal memory footprint ([f58c331](https://github.com/syntropy-systems-oss/whirr/commit/f58c331572e2315167d3eac6477a19814c820fb6))


### Bug Fixes

* remove default password from docker-compose.yml ([99c750e](https://github.com/syntropy-systems-oss/whirr/commit/99c750e3bf5e6413e1524bb8e2c34978719af2ed))

## [0.3.0](https://github.com/syntropy-systems-oss/whirr/compare/v0.2.0...v0.3.0) (2026-01-13)


### Features

* add dashboard, compare, export commands and reproducibility features ([fa63054](https://github.com/syntropy-systems-oss/whirr/commit/fa63054a61693d45abb33f7ee5d091b5cd5cf74e))
* add server mode for multi-machine orchestration (v0.4) ([8fc53aa](https://github.com/syntropy-systems-oss/whirr/commit/8fc53aaeeb9b596607401464871123d2a031ef44))


### Bug Fixes

* SQLite threading, test assertions, and version numbering ([5926b96](https://github.com/syntropy-systems-oss/whirr/commit/5926b96a4240327429c6025de2d3808c89ca2d0c))

## [0.2.0](https://github.com/syntropy-systems-oss/whirr/compare/v0.1.0...v0.2.0) (2026-01-13)


### Features

* add v0.2 features - sweep, retry, watch, orphan detection, system metrics ([0aaba35](https://github.com/syntropy-systems-oss/whirr/commit/0aaba356a75f024636ddac60e2e1198db357ad9c))


### Documentation

* add comprehensive documentation ([47b5067](https://github.com/syntropy-systems-oss/whirr/commit/47b50670e822ab201b04cc98fde579886c9fe9c9))
